==> eiffelstudio-23.09.10.7341.tar: F_code/C1/by43.c <==
/*
 * Code for class BYTE_ARRAY_HELPER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "by43.h"
#include "eif_built_in.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BYTE_ARRAY_HELPER}.put_array_natural_16 */
void F45_978 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_NATURAL_16 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTGC;
	loc1 = RTLNS(eif_new_type(908, 0x00).id, 908, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F909_12817(RTCW(loc1), ((EIF_INTEGER_32) 2L));
	F909_12877(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	{
		/* INLINED CODE (MANAGED_POINTER.read_special_natural_8) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(loc1);
		{
			static EIF_TYPE_INDEX typarr0[] = {2141,2255,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(loc1), typarr0)));
			tr1 = RTLNSP2(typres0.id,0,ti4_1,sizeof(EIF_NATURAL_8), EIF_TRUE);
		}
		F2142_21851(RTCW(tr1), (EIF_NATURAL_8) ((EIF_INTEGER_32) 0L), ti4_1);
		F909_12846(loc1, tr1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
		/* END INLINED CODE */
	}
	loc3 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F1751_17171(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	{
		/* INLINED CODE (ARRAY.to_special) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(arg1);
		tr1 = *(EIF_REFERENCE *)(arg1);
		/* END INLINED CODE */
	}
	loc2 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTLE;
}

/* {BYTE_ARRAY_HELPER}.put_array_natural_32 */
void F45_982 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_NATURAL_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTGC;
	loc1 = RTLNS(eif_new_type(908, 0x00).id, 908, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F909_12817(RTCW(loc1), ((EIF_INTEGER_32) 4L));
	F909_12878(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	{
		/* INLINED CODE (MANAGED_POINTER.read_special_natural_8) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(loc1);
		{
			static EIF_TYPE_INDEX typarr0[] = {2141,2255,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(loc1), typarr0)));
			tr1 = RTLNSP2(typres0.id,0,ti4_1,sizeof(EIF_NATURAL_8), EIF_TRUE);
		}
		F2142_21851(RTCW(tr1), (EIF_NATURAL_8) ((EIF_INTEGER_32) 0L), ti4_1);
		F909_12846(loc1, tr1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
		/* END INLINED CODE */
	}
	loc3 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F1751_17171(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	{
		/* INLINED CODE (ARRAY.to_special) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(arg1);
		tr1 = *(EIF_REFERENCE *)(arg1);
		/* END INLINED CODE */
	}
	loc2 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTLE;
}

/* {BYTE_ARRAY_HELPER}.put_array_natural_32_with_integer_32 */
void F45_984 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_32 tu4_1;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTGC;
	loc1 = RTLNS(eif_new_type(908, 0x00).id, 908, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F909_12817(RTCW(loc1), ((EIF_INTEGER_32) 4L));
	{
		/* INLINED CODE (MANAGED_POINTER.put_integer_32_le) */
		(void) RTCW(loc1);
		tu4_1 = (EIF_NATURAL_32) arg2;
		F909_12878(loc1, tu4_1, ((EIF_INTEGER_32) 0L));
		/* END INLINED CODE */
	}
	;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	{
		/* INLINED CODE (MANAGED_POINTER.read_special_natural_8) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(loc1);
		{
			static EIF_TYPE_INDEX typarr0[] = {2141,2255,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(loc1), typarr0)));
			tr1 = RTLNSP2(typres0.id,0,ti4_1,sizeof(EIF_NATURAL_8), EIF_TRUE);
		}
		F2142_21851(RTCW(tr1), (EIF_NATURAL_8) ((EIF_INTEGER_32) 0L), ti4_1);
		F909_12846(loc1, tr1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
		/* END INLINED CODE */
	}
	loc3 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F1751_17171(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	{
		/* INLINED CODE (ARRAY.to_special) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(arg1);
		tr1 = *(EIF_REFERENCE *)(arg1);
		/* END INLINED CODE */
	}
	loc2 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTLE;
}

/* {BYTE_ARRAY_HELPER}.put_array_integer_16 */
void F45_987 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_16 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_16 tu2_1;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTGC;
	loc1 = RTLNS(eif_new_type(908, 0x00).id, 908, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F909_12817(RTCW(loc1), ((EIF_INTEGER_32) 2L));
	{
		/* INLINED CODE (MANAGED_POINTER.put_integer_16_le) */
		(void) RTCW(loc1);
		tu2_1 = (EIF_NATURAL_16) arg2;
		F909_12877(loc1, tu2_1, ((EIF_INTEGER_32) 0L));
		/* END INLINED CODE */
	}
	;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	{
		/* INLINED CODE (MANAGED_POINTER.read_special_natural_8) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(loc1);
		{
			static EIF_TYPE_INDEX typarr0[] = {2141,2255,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(loc1), typarr0)));
			tr1 = RTLNSP2(typres0.id,0,ti4_1,sizeof(EIF_NATURAL_8), EIF_TRUE);
		}
		F2142_21851(RTCW(tr1), (EIF_NATURAL_8) ((EIF_INTEGER_32) 0L), ti4_1);
		F909_12846(loc1, tr1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
		/* END INLINED CODE */
	}
	loc3 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F1751_17171(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	{
		/* INLINED CODE (ARRAY.to_special) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(arg1);
		tr1 = *(EIF_REFERENCE *)(arg1);
		/* END INLINED CODE */
	}
	loc2 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTLE;
}

void EIF_Minit43 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C1/by43.c <==
/*
 * Code for class BYTE_ARRAY_HELPER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "by43.h"
#include "eif_built_in.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BYTE_ARRAY_HELPER}.put_natural_16 */
void F45_975 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_NATURAL_16 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTGC;
	loc1 = RTLNS(eif_new_type(933, 0x00).id, 933, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F934_13177(RTCW(loc1), ((EIF_INTEGER_32) 2L));
	F934_13237(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	{
		/* INLINED CODE (MANAGED_POINTER.read_special_natural_8) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(loc1);
		{
			static EIF_TYPE_INDEX typarr0[] = {2152,2272,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(loc1), typarr0)));
			tr1 = RTLNSP2(typres0.id,0,ti4_1,sizeof(EIF_NATURAL_8), EIF_TRUE);
		}
		F2153_22049(RTCW(tr1), (EIF_NATURAL_8) ((EIF_INTEGER_32) 0L), ti4_1);
		F934_13206(loc1, tr1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
		/* END INLINED CODE */
	}
	loc3 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F1761_17340(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	{
		/* INLINED CODE (ARRAY.to_special) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(arg1);
		tr1 = *(EIF_REFERENCE *)(arg1);
		/* END INLINED CODE */
	}
	loc2 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTLE;
}

/* {BYTE_ARRAY_HELPER}.put_natural_32 */
void F45_976 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_NATURAL_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTGC;
	loc1 = RTLNS(eif_new_type(933, 0x00).id, 933, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F934_13177(RTCW(loc1), ((EIF_INTEGER_32) 4L));
	F934_13238(RTCW(loc1), arg2, ((EIF_INTEGER_32) 0L));
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	{
		/* INLINED CODE (MANAGED_POINTER.read_special_natural_8) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(loc1);
		{
			static EIF_TYPE_INDEX typarr0[] = {2152,2272,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(loc1), typarr0)));
			tr1 = RTLNSP2(typres0.id,0,ti4_1,sizeof(EIF_NATURAL_8), EIF_TRUE);
		}
		F2153_22049(RTCW(tr1), (EIF_NATURAL_8) ((EIF_INTEGER_32) 0L), ti4_1);
		F934_13206(loc1, tr1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
		/* END INLINED CODE */
	}
	loc3 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F1761_17340(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	{
		/* INLINED CODE (ARRAY.to_special) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(arg1);
		tr1 = *(EIF_REFERENCE *)(arg1);
		/* END INLINED CODE */
	}
	loc2 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTLE;
}

/* {BYTE_ARRAY_HELPER}.put_integer_16 */
void F45_979 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_16 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_16 tu2_1;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTGC;
	loc1 = RTLNS(eif_new_type(933, 0x00).id, 933, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F934_13177(RTCW(loc1), ((EIF_INTEGER_32) 2L));
	{
		/* INLINED CODE (MANAGED_POINTER.put_integer_16_le) */
		(void) RTCW(loc1);
		tu2_1 = (EIF_NATURAL_16) arg2;
		F934_13237(loc1, tu2_1, ((EIF_INTEGER_32) 0L));
		/* END INLINED CODE */
	}
	;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	{
		/* INLINED CODE (MANAGED_POINTER.read_special_natural_8) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(loc1);
		{
			static EIF_TYPE_INDEX typarr0[] = {2152,2272,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(loc1), typarr0)));
			tr1 = RTLNSP2(typres0.id,0,ti4_1,sizeof(EIF_NATURAL_8), EIF_TRUE);
		}
		F2153_22049(RTCW(tr1), (EIF_NATURAL_8) ((EIF_INTEGER_32) 0L), ti4_1);
		F934_13206(loc1, tr1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
		/* END INLINED CODE */
	}
	loc3 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F1761_17340(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	{
		/* INLINED CODE (ARRAY.to_special) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(arg1);
		tr1 = *(EIF_REFERENCE *)(arg1);
		/* END INLINED CODE */
	}
	loc2 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTLE;
}

/* {BYTE_ARRAY_HELPER}.put_integer_32 */
void F45_980 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_INTEGER_32 ti4_4;
	EIF_NATURAL_32 tu4_1;
	EIF_NATURAL_8 tu1_1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,loc3);
	RTLR(2,tr1);
	RTLR(3,arg1);
	RTLR(4,loc2);
	RTLIU(5);
	
	RTGC;
	loc1 = RTLNS(eif_new_type(933, 0x00).id, 933, _OBJSIZ_0_1_0_1_0_1_1_0_);
	F934_13177(RTCW(loc1), ((EIF_INTEGER_32) 4L));
	{
		/* INLINED CODE (MANAGED_POINTER.put_integer_32_le) */
		(void) RTCW(loc1);
		tu4_1 = (EIF_NATURAL_32) arg2;
		F934_13238(loc1, tu4_1, ((EIF_INTEGER_32) 0L));
		/* END INLINED CODE */
	}
	;
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_0_1_0_0_);
	{
		/* INLINED CODE (MANAGED_POINTER.read_special_natural_8) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(loc1);
		{
			static EIF_TYPE_INDEX typarr0[] = {2152,2272,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(loc1), typarr0)));
			tr1 = RTLNSP2(typres0.id,0,ti4_1,sizeof(EIF_NATURAL_8), EIF_TRUE);
		}
		F2153_22049(RTCW(tr1), (EIF_NATURAL_8) ((EIF_INTEGER_32) 0L), ti4_1);
		F934_13206(loc1, tr1, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
		/* END INLINED CODE */
	}
	loc3 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	F1761_17340(RTCW(arg1), (EIF_INTEGER_32) (arg3 + ti4_1));
	{
		/* INLINED CODE (ARRAY.to_special) */
		tr1 = (EIF_REFERENCE)  0;
		(void) RTCW(arg1);
		tr1 = *(EIF_REFERENCE *)(arg1);
		/* END INLINED CODE */
	}
	loc2 = tr1;
	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (loc3);
	/* INLINED CODE (SPECIAL.copy_data) */
	memmove((EIF_NATURAL_8 *)RTCW(loc2) + (arg3),(EIF_NATURAL_8 *)loc3 + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)ti4_1);
	RT_SPECIAL_COUNT(loc2) = eif_max_int32(RT_SPECIAL_COUNT(loc2), arg3 + ti4_1);
	/* END INLINED CODE */
	;
	RTLE;
}

void EIF_Minit43 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
